OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "وحدة التخزين غير متوفرة مؤقتاً",
    "Storage invalid" : "وحدة تخزين غير صالحه ",
    "Unknown error" : "خطأ غير معروف. ",
    "All files" : "كل الملفات",
    "Saved" : "تم الحفظ",
    "There was an error saving" : "حدث خطأ أثناء الحفظ",
    "File could not be found" : "لم يتم العثور على الملف",
    "Home" : "البيت",
    "Close" : "إغلاق",
    "Favorites" : "المفضلة ",
    "Could not create folder \"{dir}\"" : "لا يمكن إنشاء المجلد \"{dir}\"",
    "Upload cancelled." : "تم إلغاء عملية رفع الملفات .",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "لا يوجد مساحة تخزين كافية، انت تقوم برفع {size1} ولكن المساحه المتوفره هي {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "المجلد المطلوب \"{dir}\" لم يعد موجودا",
    "Not enough free space" : "لا يوجد سعة تخزين كافية",
    "Uploading..." : "تحميل",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} من {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "عملية تحميل الملفات قيد التنفيذ. اغلاق الصفحة سوف يلغي عملية تحميل الملفات.",
    "Actions" : "* تطبيقات.\n* أنشطة.",
    "Download" : "تحميل",
    "Rename" : "إعادة التسمية",
    "Delete" : "حذف ",
    "Disconnect storage" : "وحدة تخزين مفصولة",
    "Unshare" : "إلغاء المشاركة",
    "Could not load info for file \"{file}\"" : "لم يتم تحميل معلومات الملف \"{file}\"",
    "Files" : "الملفات",
    "Details" : "تفاصيل",
    "Select" : "اختار",
    "Pending" : "قيد الانتظار",
    "Unable to determine date" : "تعذر تحديد التاريخ",
    "Invalid path" : "مسار غير صحيح",
    "This operation is forbidden" : "هذة العملية ممنوعة ",
    "This directory is unavailable, please check the logs or contact the administrator" : "المجلد غير متاح، الرجاء التواصل مع مسؤول النظام ",
    "Could not move \"{file}\", target exists" : "تعذر نقل الملف \"{file}\"، الملف موجود",
    "Could not move \"{file}\"" : "تعذر نقل الملف \"{file}\"",
    "{newName} already exists" : "{newName} موجود فعلا",
    "Could not rename \"{fileName}\", it does not exist any more" : "تعذر اعادة تسمية \"{fileName}\"، الملف غير موجود",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{targetName}\" مستخدم في الملجد \"{dir}\". الرجاء اختيار اسم اخر",
    "Could not rename \"{fileName}\"" : "تعذر اعادة تسمية الملف \"{fileName}\"",
    "Could not create file \"{file}\"" : "لا يمكن إنشاء الملف\"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "لا يمكن إنشاء الملف \"{file}\" فهو موجود بالفعل",
    "Could not create folder \"{dir}\" because it already exists" : "لا يمكن إنشاء المجلد \"{dir}\" فهو موجود بالفعل",
    "Error deleting file \"{fileName}\"." : "خطأ أثناء حذف الملف \"{fileName}\".",
    "Name" : "اسم",
    "Size" : "حجم",
    "Modified" : "معدل",
    "_%n folder_::_%n folders_" : ["لا يوجد مجلدات %n","1 مجلد %n","2 مجلد %n","عدد قليل من مجلدات %n","عدد كبير من مجلدات %n","مجلدات %n"],
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","ملف %n","2 ملف %n","قليل من ملفات %n","الكثير من ملفات %n"," ملفات %n"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "You don’t have permission to upload or create files here" : "لا تملك الصلاحية لرفع او انشاء ملف هنا ",
    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","يتم تحميل ملفات %n"],
    "New" : "جديد",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "مساحة تخزين {owner} ممتلئة، لا يمكن تحديث الملفات او مزامنتها بعد الان !",
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "المساحة التخزينية لـ {owner} ممتلئة تقريبا ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "مساحتك التخزينية امتلأت تقريبا ",
    "Path" : "المسار",
    "Favorited" : "قمت بتفضيلها",
    "Favorite" : "المفضلة",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "رابط خاص: فقط المستخدمين الذين لهم صلاحية الوصول الى هذا الملف او المجد بامكانهم استخدامه. استخدم هذا الرابط كرابط دائم لك ",
    "Folder" : "مجلد",
    "New folder" : "مجلد جديد",
    "{newname} already exists" : "{newname} موجود مسبقاً",
    "Upload" : "رفع",
    "An error occurred while trying to update the tags" : "حدث خطأ اثناء محاولة تحديث tags",
    "A new file or folder has been <strong>created</strong>" : "تم <strong>  إنشاء</strong> ملف جديد أو مجلد ",
    "A file or folder has been <strong>changed</strong>" : "تم  <strong> تغيير</strong> ملف أو مجلد",
    "A file or folder has been <strong>deleted</strong>" : "تم <strong>حذف </strong> ملف أو مجلد",
    "A file or folder has been <strong>restored</strong>" : "تم <strong> استعادة </strong> ملف أو مجلد",
    "You created %1$s" : "لقد أنشأت %1$s",
    "%2$s created %1$s" : "%2$s أنشأ %1$s",
    "%1$s was created in a public folder" : "تم إنشاء %1$s في مجلد عام",
    "You changed %1$s" : "لقد غيرت %1$s",
    "%2$s changed %1$s" : "%2$s غير %1$s",
    "You deleted %1$s" : "حذفت %1$s",
    "%2$s deleted %1$s" : "%2$s حذف %1$s",
    "You restored %1$s" : "لقد قمت باستعادة %1$s",
    "%2$s restored %1$s" : "%2$s مستعاد %1$s",
    "Changed by %2$s" : "اخر تعديل بواسطة %2$s",
    "Deleted by %2$s" : "تم الحذف بواسطة %2$s",
    "Restored by %2$s" : "تمت الإستعادة بواسطة  %2$s",
    "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
    "File handling" : "التعامل مع الملف",
    "Maximum upload size" : "الحد الأقصى لحجم الملفات التي يمكن رفعها",
    "max. possible: " : "الحد الأقصى المسموح به",
    "Save" : "حفظ",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "باستخدام PHP-FPM، التعديلات سوف تستغرق 5 دقائق للتفعيل",
    "Missing permissions to edit from here." : "لا يوجد إذن للتعديل من هنا ",
    "Settings" : "إعدادات",
    "Show hidden files" : "عرض الملفات المخفية",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "استخدم هذا الرابط <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> الوصول للملفات</a>",
    "No files in here" : "لا يوجد ملفات هنا ",
    "Upload some content or sync with your devices!" : "ارفع بعض المحتوي او زامن مع اجهزتك !",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Select all" : "تحديد الكل ",
    "Upload too large" : "حجم الترفيع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
    "No favorites" : "لا يوجد مفضلات ",
    "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كامفضلة سوف تظهر هنا ",
    "Text file" : "ملف نصي",
    "New text file.txt" : "ملف نصي جديد fille.txt",
    "Processing files..." : "جارٍ معالجة الملفات ...",
    "Target folder does not exist any more" : "المجلد الهدف غير موجود بعد الآن",
    "Error when assembling chunks, status code {status}" : "خطأ عند تجميع القطع ، رمز الحالة {status}",
    "No entries in this folder match {filter}" : "لا يوجد في هذا المجلد إدخالات تتطابق مع {filter}",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "الحد من الإخطارات حول تغييرات\n<strong>ملفاتك المفضلة</strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "ليس مرخصا لك الوصول إلى هذا الملف أو المجلد - يرجى الاتصال بالمالك لمشاركة الترخيص معك."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
